#!/usr/bin/env node

const { execSync } = require('child_process');
const fs = require('fs');
const path = require('path');
const readline = require('readline');
const { copySync } = require('fs-extra');

const rl = readline.createInterface({
  input: process.stdin,
  output: process.stdout
});

function askQuestion(query) {
  return new Promise(resolve => rl.question(query, resolve));
}

async function main() {
  console.log("🚀 Welcome to My Dashboard CLI!");

  const projectName = await askQuestion("Enter your project name: ");
  const targetDir = path.resolve(process.cwd(), projectName.trim());

  if (fs.existsSync(targetDir)) {
    console.log("❌ Directory already exists. Please choose another name.");
    process.exit(1);
  }

  console.log("🛠 Creating your project...");
  copySync(path.join(__dirname, 'template'), targetDir);

  console.log("📦 Installing dependencies...");
  execSync(`cd ${projectName} && npm install`, { stdio: 'inherit' });

  console.log("✅ Done! Your dashboard is ready.");
  rl.close();
}

main();